description

# XMLRésuméLibrary: User Guide

degrees | Element Reference | docpath

## Name

description — An explanation of something

## Synopsis

### Content Model

    (para+)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `description` element specifies a person's role, their activities, or other descriptive information.

### Parents

`description` may be contained in these elements: `award`, `interest`, `job`, `membership`

## See Also

`projects`, `achievements`.

## Examples

    <job>
      <jobtitle>Supersonic Vacuum Technician</jobtitle>
      <employer>Joe's Vacuum Shop</employer>
      <period>
        <from><date><month>June</month><year>2344</year></date></from>
        <to><present/></to>
      </period>
      <description>
        Repaired hyperdynamic microbial particle accelerators in Supersonic vacuum
        models XL144 and XP2000.
      </description>
    </job>

    <membership>
      <title>Treasurer</title>
      <organization>Mars Vacuum Repair Association</organization>
      <description>
        Kept books and collected membership dues.
      </description>
    </job>

degrees | Element Reference | docpath